@@ -122,7 +122,7 @@ theme_dag_gray_grid <- theme_dag_grey_grid
 scale_adjusted <- function() {
   list(
     ggplot2::scale_linetype_manual(name = NULL, values = "dashed"),
-    ggplot2::scale_shape_manual(drop = FALSE, values = c("unadjusted" = 19, "adjusted" = 15)),
+    ggplot2::scale_shape_manual(drop = FALSE, values = c("adjusted" = 15, "unadjusted" = 19)),
     ggplot2::scale_alpha_manual(drop = FALSE, values = c("adjusted" = .30, "unadjusted" = 1)),
     ggraph::scale_edge_alpha_manual(name = NULL, drop = FALSE, values = c("adjusted" = .30, "unadjusted" = 1))
   )
@@ -154,7 +154,7 @@ scale_dag <- function(breaks = ggplot2::waiver()) {
 #' @export
 #'
 #' @examples
-#'
+#' library(ggplot2)
 #' ggdag(confounder_triangle()) +
 #' theme_bw() +
 #' remove_axes()
